import os
import json
import sys

import lz4.block

__version__ = "0.1.2"


def get_firefox_urls(mozziladir="~/.mozilla"):
    for parentdir, dirs, files in os.walk(os.path.expanduser(mozziladir)):
        if "recovery.jsonlz4" in files:
            break
    else:
        print("Could not find recovery.jsonlz4 in ~/.mozilla")

    filename = os.path.join(parentdir, "recovery.jsonlz4")

    with open(filename, "rb") as f:
        # the first 8 bytes in recovery.jsonlz4 should contain
        # the string mozLz40
        assert f.read(8) == b"mozLz40\0"
        # after these 8 bytes the file is a lz4 stream
        compressed_data = f.read()

    data = lz4.block.decompress(compressed_data)
    root = json.loads(data.decode("utf-8"))

    for w, window in enumerate(root["windows"]):
        for t, tab in enumerate(window["tabs"]):
            yield w, t, tab["entries"][tab["index"]-1]["url"]


def main():
    for w, t, url in get_firefox_urls():
        print("window %d tab %d: %s" % (w, t, url))



from setuptools import setup
from os import path
import re


def packagefile(*relpath):
    return path.join(path.dirname(__file__), *relpath)


def read(*relpath):
    with open(packagefile(*relpath)) as f:
        return f.read()


def get_version(*relpath):
    match = re.search(
        r'''^__version__ = ['"]([^'"]*)['"]''',
        read(*relpath),
        re.M
    )
    if not match:
        raise RuntimeError('Unable to find version string.')
    return match.group(1)


setup(
    name='get_firefox_urls',
    version=get_version('get_firefox_urls.py'),
    description='Utility to print the URLs currently open in Firefox.',
    long_description=read('README.rst'),
    url='https://github.com/luismsgomes/get-firefox-urls',
    author='Luís Gomes',
    author_email='luismsgomes@gmail.com',
    license='MIT',
    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.7',
    ],
    keywords='firefox util commandline',
    install_requires=['lz4'],
    py_modules=['get_firefox_urls'],
    entry_points={
        'console_scripts': [
            'get-firefox-urls=get_firefox_urls:main',
        ],
    },
)
